@@ -26,6 +26,7 @@
 #' @param less_conservative_se less_conservative_se
 #' @param continuous continuous
 #' @returns A dataframe with the by_path classifier
+#' @import data.table
 #' @noRd
 
 did_multiplegt_by_path <- function(
@@ -56,20 +57,21 @@ did_multiplegt_by_path <- function(
     continuous,
     by_path
     ) {
-    
+
     data <- did_multiplegt_main(df = df, outcome = outcome, group =  group, time =  time, treatment = treatment, effects = effects, placebo = placebo, ci_level = ci_level,switchers = switchers, trends_nonparam = trends_nonparam, weight = weight, controls = controls, dont_drop_larger_lower = dont_drop_larger_lower, drop_if_d_miss_before_first_switch = drop_if_d_miss_before_first_switch, cluster = cluster, same_switchers = same_switchers, same_switchers_pl = same_switchers_pl, only_never_switchers = only_never_switchers, effects_equal = effects_equal, save_results = save_results, normalized = normalized, predict_het = predict_het, trends_lin = trends_lin, less_conservative_se = less_conservative_se, continuous = continuous, data_only = TRUE)
-    class(data$df) <- "data.frame"
 
     design_base <- did_multiplegt_dyn_design(data = data, design_opt = list(1, "console"), weight = weight, by = NULL, by_index = "_no_by", append = FALSE)
 
+    path_index <- copy(data$df)
     l_XX <- data$l_XX
     T_max_XX <- data$T_max_XX
-    path_index <- data$df[c("group", "time", "time_XX", "treatment_XX", "F_g_XX")]
+    path_index <- path_index[, c("group", "time", "time_XX", "treatment_XX", "F_g_XX"), with = TRUE]
+
     data <- NULL
     if (by_path == -1) {
         by_path <- nrow(design_base$design_mat)
     }
-    design_set <- design_base$design_mat[1:min(by_path, nrow(design_base$design_mat)), ]
+    design_set <- matrix(design_base$design_mat[1:min(by_path, nrow(design_base$design_mat)), ], ncol = ncol(design_base$design_mat), nrow = min(by_path, nrow(design_base$design_mat)))
     if (by_path > nrow(design_base$design_mat)) {
         message(sprintf("You requested %.0f treatment paths, but there are only %.0f paths in your data. The program will continue with the latter number of treatment paths."))
     }
@@ -83,8 +85,10 @@ did_multiplegt_by_path <- function(
     }
     path_index$treatment_XX <- NULL
     for (j in 0:l_XX) {
-        path_index <- path_index %>% group_by(.data$group) %>% 
-            mutate(!!paste0("D_fg",j) := mean(.data[[paste0("D_Fg",j)]],na.rm = TRUE)) %>% ungroup()
+        path_index[, paste0("D_fg",j) := mean(get(paste0("D_Fg",j)), na.rm = TRUE), by = c("group")]
+    }
+
+    for (j in 0:l_XX) {
         path_index[[paste0("D_Fg",j)]] <- NULL
     }
 
@@ -97,8 +101,8 @@ did_multiplegt_by_path <- function(
     path_index$yet_to_switch_XX <- as.numeric(path_index$time_XX < path_index$F_g_XX)
     path_index$time_XX <- path_index$F_g_XX <- NULL
     path_index$baseline_XX <- substr(path_index$path,1,1)
-    names(path_index) <- c(group, time, "path_XX", "yet_to_switch_XX", "baseline_XX")
 
+    path_index <- data.table::setnames(path_index, old =  c("group", "time", "path", "yet_to_switch_XX", "baseline_XX"), new =  c(group, time, "path_XX", "yet_to_switch_XX", "baseline_XX"))
     df <- merge(df, path_index, by = c(group, time))
     df <- df[order(df[[group]], df[[time]]), ]
     data <- list(df = df, path = path)
